@@ -141,6 +141,10 @@ class DenseBase(Operator):
         self.set_rule(('.', HomothetyOperator), self._rule_homothety,
                       CompositionOperator)
 
+    @property
+    def nbytes(self):
+        return self.data.nbytes
+
     def validatein(self, shape):
         if len(shape) < self.naxesin or shape[-self.naxesin:] != self._sn:
             return ValueError(
@@ -209,8 +213,9 @@ class DenseBlockDiagonalOperator(DenseBase):
             extrashapein = self.shapein[:-self.naxesin]
             if broadcast_shapes(extrashapein, self._sl) != extrashapein:
                 raise NotImplementedError(
-                    'With this input shape, the operator is not diagonal block'
-                    ' anymore. Its transpose would not be correct.')
+                    'With this explicit input shape, the operator is not diago'
+                    'nal block anymore. Its transpose would not be incorrect a'
+                    'nd DenseBlockColumnOperator is not yet implemented.')
         self.set_rule(('.', DenseBlockDiagonalOperator), self._rule_mul,
                       CompositionOperator)
 
@@ -929,6 +934,11 @@ class TridiagonalOperator(Operator):
         output[:-1] += self.subdiagonal * input[1:]
         output[1:] += self.superdiagonal * input[:-1]
 
+    @property
+    def nbytes(self):
+        return self.diagonal.nbytes + self.subdiagonal.nbytes + \
+               self.superdiagonal.nbytes
+
     def todense(self):
         #XXX optimize me
         out = np.zeros(self.shape, dtype=self.dtype)
@@ -1043,6 +1053,10 @@ class BandOperator(Operator):
             # lower part
             out[i:] += rab[i + 1, :-i] * x[:-i]
 
+    @property
+    def nbytes(self):
+        return self.ab.nbytes
+
     def diag(self, i=0):
         """
         Returns the i-th diagonal (subdiagonal if i < 0, superdiagonal
@@ -1125,6 +1139,10 @@ class SymmetricBandOperator(Operator):
             # lower part
             out[i:] += self.ab[i, :-i] * x[:-i]
 
+    @property
+    def nbytes(self):
+        return self.ab.nbytes
+
     @property
     def rab(self):
         return self.ab
@@ -1251,6 +1269,10 @@ class SymmetricBandToeplitzOperator(Operator):
                     self.bplan.execute()
                     out_[...] = rbuffer[lpad:lpad+self.nsamples]
 
+    @property
+    def nbytes(self):
+        return self.kernel.nbytes
+
     def _get_kernel(self, firstrow, fplan, rbuffer, cbuffer, ncorr, fftsize,
                     dtype):
         firstrow = firstrow.reshape((-1, ncorr + 1))
@@ -1342,6 +1364,10 @@ class EigendecompositionOperator(CompositionOperator):
         CompositionOperator.__init__(self, [V, W, V.T], **kwargs)
         self.set_rule('I', lambda s: s ** -1)
 
+    @property
+    def nbytes(self):
+        return self.eigenvalues.nbytes + self.eigenvectors.nbytes
+
     def det(self):
         """
         Output an approximation of the determinant from the
