@@ -9,7 +9,8 @@ import numpy as np
 from .core import (
     Operator, BlockColumnOperator, CompositionOperator, ConstantOperator,
     IdentityOperator, MultiplicationOperator, ReductionOperator)
-from .flags import idempotent, inplace, real, separable, square
+from .flags import (
+    idempotent, inplace, real, separable, square, update_output)
 from .linear import DegreesOperator, RadiansOperator
 from .utils import (
     operation_assignment, operation_symbol, pi, strenum, tointtuple)
@@ -252,6 +253,10 @@ class ClipOperator(Operator):
     def direct(self, input, output):
         np.clip(input, self.minvalue, self.maxvalue, out=output)
 
+    @property
+    def nbytes(self):
+        return self.minvalue.nbytes + self.maxvalue.nbytes
+
     def __str__(self):
         return 'clip(..., {0}, {1})'.format(self.minvalue, self.maxvalue)
 
@@ -295,6 +300,10 @@ class PowerOperator(Operator):
     def direct(self, input, output):
         np.power(input, self.n, output)
 
+    @property
+    def nbytes(self):
+        return self.n.nbytes
+
     def __str__(self):
         return '...**{0}'.format(self.n)
 
@@ -514,6 +523,10 @@ class MaximumOperator(Operator):
     def direct(self, input, output):
         np.maximum(input, self.value, output)
 
+    @property
+    def nbytes(self):
+        return self.value.nbytes
+
     def __str__(self):
         return 'maximum(..., {0})'.format(self.value)
 
@@ -551,6 +564,10 @@ class MinimumOperator(Operator):
     def direct(self, input, output):
         np.minimum(input, self.value, output)
 
+    @property
+    def nbytes(self):
+        return self.value.nbytes
+
     def __str__(self):
         return 'minimum(..., {0})'.format(self.value)
 
@@ -577,6 +594,7 @@ class NormalizeOperator(Operator):
 
 @square
 @inplace
+@update_output
 class NumexprOperator(Operator):
     """
     Return an operator evaluating an expression using numexpr.
@@ -602,7 +620,8 @@ class NumexprOperator(Operator):
         self.expr = expr
         self.global_dict = global_dict
         if numexpr.__version__ < '2.1':
-            self._disable_inplace_reduction = True
+            keywords['flags'] = self.validate_flags(
+                keywords.get('flags', {}), update_output=False)
         Operator.__init__(self, dtype=dtype, **keywords)
 
     def direct(self, input, output, operation=operation_assignment):
@@ -613,6 +632,13 @@ class NumexprOperator(Operator):
             expr = 'output' + op + '(' + self.expr + ')'
         numexpr.evaluate(expr, global_dict=self.global_dict, out=output)
 
+    @property
+    def nbytes(self):
+        if self.global_dict is None:
+            return 0
+        return np.sum(v.nbytes for v in self.global_dict.values()
+                               if hasattr(v, 'nbytes'))
+
     def __str__(self):
         return 'numexpr({0}, ...)'.format(self.expr)
 
@@ -722,6 +748,10 @@ class HardThresholdingOperator(Operator):
     def direct(self, input, output):
         hard_thresholding(input, self.a, output)
 
+    @property
+    def nbytes(self):
+        return self.a.nbytes
+
     def __str__(self):
         return 'hardthreshold(..., {0})'.format(self.a)
 
@@ -759,6 +789,10 @@ class SoftThresholdingOperator(Operator):
     def direct(self, input, output):
         soft_thresholding(input, self.a, output)
 
+    @property
+    def nbytes(self):
+        return self.a.nbytes
+
     def __str__(self):
         return 'softthreshold(..., {0})'.format(self.a)
 
